@@ -39,13 +39,13 @@ def _update_latest_processed_timestamp(consumer, latest_timestamp):
     _ = table.put_item(Item=item)
 
 
-def _get_metadata_from_dynamodb(consumer, latest_timestamp):
+def _get_metadata_from_dynamodb(data_source, latest_timestamp):
     """
     query dynamodb to get location (bucket_name, file_name) of one batch data after input timestamp
     get from meta-data tables (dynamo)
     """
 
-    table = _get_or_create_metadata_table(consumer) 
+    table = _get_or_create_metadata_table(data_source)
     print('table status :', table.table_status)
 
     if latest_timestamp is None:  # haven't processed any job yet
@@ -98,12 +98,12 @@ def _get_metadata_from_dynamodb(consumer, latest_timestamp):
         return None
 
 
-def _get_one_batch_after_timestamp(consumer, latest_timestamp):
+def _get_one_batch_after_timestamp(data_source, latest_timestamp):
     """
     get from S3
     """
 
-    metadata = _get_metadata_from_dynamodb(consumer, latest_timestamp)
+    metadata = _get_metadata_from_dynamodb(data_source, latest_timestamp)
     if metadata is None:
         return None, None
 
@@ -111,7 +111,7 @@ def _get_one_batch_after_timestamp(consumer, latest_timestamp):
     return batch, metadata["timestamp"], metadata['file_name'], metadata
     
 
-def start_processor(process, consumer='matching', data_source='main-foodProject'):
+def start_processor(process, consumer, data_source):
     latest_timestamp = _get_latest_processed_timestamp(f'{consumer}-{data_source}')  # from state
     while True:
         print('latest_timestamp before : ', latest_timestamp)
